Feature Aggregation Transforms
============================

This module contains transformations for feature aggregation tasks.

.. automodule:: atomworks.ml.transforms.feature_aggregation
   :members:
   :undoc-members:
   :show-inheritance: 